Miyawaki 2008


Notes
-----
Collection of result images from MVPA investigation of the human visual systems.

This :term:`fMRI` study reconstructed visual images by combining local
image bases of multiple scales. Their :term:`contrasts<contrast>` were independently
decoded from :term:`fMRI` activity by selecting important :term:`voxels<voxel>` and
capitalizing on their correlation structure.

Content
-------
    :'label': Paths to text files containing session and target data
    :'func': Paths to nifti files with :term:`BOLD` data
    :'mask': Path to general mask nifti that defines target volume in visual cortex
    :'mask_roi': List of paths to images with specific data ('RH' for right hemisphere, 'LH' for left hemisphere, 'Vxxx' denote visual areas)


References
----------
For more information on this dataset's structure, see
http://www.cns.atr.jp/dni/en/downloads/ fmri-data-set-for-visual-image-reconstruction

Miyawaki, Y., Uchida, H., Yamashita, O., Sato, M. A.,
Morito, Y., Tanabe, H. C., ... & Kamitani, Y. (2008).
Neuron, 60(5), 915-929.

Licence: unknown.
